Properties Methods Events Config Options Direct Link

# Class Ext.ux.TabScrollerMenu

Package: | Ext.ux
Defined In: | ux-all-debug.js
Class: | TabScrollerMenu
Extends: | Object

Plugin (ptype = 'tabscrollermenu') for adding a tab scroller menu to tabs.

## Config Options

Config Options | Defined By
--- | ---
| maxText : Number How long should the title of each Ext.menu.Item be. | TabScrollerMenu
| maxText : Number How long should the title of each Ext.menu.Item be. | TabScrollerMenu
| menuPrefixText : String Text to prefix the submenus. | TabScrollerMenu
| menuPrefixText : String Text to prefix the submenus. | TabScrollerMenu
| pageSize : Number How many items to allow per submenu. | TabScrollerMenu
| pageSize : Number How many items to allow per submenu. | TabScrollerMenu

## Public Properties

This class has no public properties.

## Public Methods

Method | Defined By
--- | ---
| TabScrollerMenu( `Object config` ) Parameters: `config` : Object Configuration options Returns: void | TabScrollerMenu
| getMaxText() : Number Returns the current maxText length; Returns the current maxText length; Parameters: None. Returns: `Number` this.maxText The current max text length. | TabScrollerMenu
| getMenuPrefixText() : String Returns the current menu prefix text String.; Returns the current menu prefix text String.; Parameters: None. Returns: `String` this.menuPrefixText The current menu prefix text. | TabScrollerMenu
| getPageSize() : Number Returns an the current page size (this.pageSize); Returns an the current page size (this.pageSize); Parameters: None. Returns: `Number` this.pageSize The current page size. | TabScrollerMenu
| setMaxText( `Number t` ) : void Sets the maximum text size for each menu item. Sets the maximum text size for each menu item. Parameters: `t` : Number The max text per each menu item. Returns: void | TabScrollerMenu
| setMenuPrefixText( `String t` ) : void Sets the menu prefix text String. Sets the menu prefix text String. Parameters: `t` : String The menu prefix text. Returns: void | TabScrollerMenu
| setPageSize( `Number pageSize` ) : void Sets the number of menu items per submenu "page size". Sets the number of menu items per submenu "page size". Parameters: `pageSize` : Number The page size Returns: void | TabScrollerMenu

## Public Events

This class has no public events.